@@ -1,7 +1,7 @@
-coefs.plsRbeta <- function(dataset, ind, nt, modele, family=NULL, method="logistic", link=NULL, link.phi=NULL, type="ML") 
+coefs.plsRbeta <- function(dataset, ind, nt, modele, family=NULL, method="logistic", link=NULL, link.phi=NULL, type="ML",verbose=TRUE) 
 {
     tempcoefs <- try(PLS_beta_wvc(dataY = dataset[ind, 1], dataX = dataset[ind, 
-        -1], nt = nt, modele = modele, family=family, method=method, link=link, keepstd.coeffs = TRUE, link.phi=link.phi, type=type)$std.coeffs, silent=TRUE)
+        -1], nt = nt, modele = modele, family=family, method=method, link=link, keepstd.coeffs = TRUE, link.phi=link.phi, type=type, verbose=verbose)$std.coeffs, silent=TRUE)
     if (is.numeric(tempcoefs)) {
         return(tempcoefs)
     }
